@@ -10,7 +10,7 @@ use Const::Fast;
 use DateTime::Format::HTTP;
 use HTTP::Date;
 
-our $VERSION        = '3.0';
+our $VERSION        = '3.1';
 
 our $DateTimeCreate    = 1;
 our $ExtractProgram    = 1;
@@ -271,17 +271,17 @@ sub parse_syslog_line {
             }
         }
         elsif( $raw_string =~ s/$REGEXP{$RegexSet}->{program_netapp}//o ) {
-            # Check for a [host thing.subthing:level]: tag, Thanks NetApp.
+            # Check for a [host thing.subthing:level]: tag
+            #          or [host:thing.subthing:level]: tag, Thanks NetApp.
             my $subStr = $1;
             $msg{program_raw} = qq{[$subStr]};
-            my $progStr = (split /\s+/, $subStr)[-1];
-            my ($program,$level) = split /\:/, $progStr;
+            my ($host,$program,$level) = split /[: ]+/, $subStr;
             $msg{program_name} = $program;
             if(!exists $msg{priority} && exists $LOG_PRIORITY{$level}) {
                 $msg{priority} = $level;
                 $msg{priority_int} = $LOG_PRIORITY{$level};
             }
-            $raw_string =~ s/^[\s:]+//;
+            $raw_string =~ s/^[ :]+//;
         }
     }
     else {
@@ -352,7 +352,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 3.0
+version 3.1
 
 =head1 SYNOPSIS
 
